@@ -1,28 +1,26 @@
-from PIL import Image, ImageDraw, ImageFont, ImageOps
 from io import BytesIO
+from PIL import Image, ImageDraw, ImageFont, ImageOps
+from magic import from_buffer
 from pathlib import Path
-from imghdr import what
 
 
 class Color:
-    # fmt: off
-    RED    = (255, 0, 0)
-    GREEN  = (0, 255, 0)
-    BLUE   = (0, 0, 255)
-    CYAN   = (0, 255, 255)
-    ORANGE = (255, 128, 0)
-    YELLOW = (255, 255, 0)
-    GREEN  = (0, 255, 0)
-    BLUE   = (0, 0, 255)
-    PURPLE = (128, 0, 255)
-    PINK   = (255, 0, 255)
-    WHITE  = (255, 255, 255)
-    GRAY   = (128, 128, 128)
-    BLACK  = (0, 0, 0)
+    RED    = (255, 0, 0, 255)
+    GREEN  = (0, 255, 0, 255)
+    BLUE   = (0, 0, 255, 255)
+    CYAN   = (0, 255, 255, 255)
+    ORANGE = (255, 128, 0, 255)
+    YELLOW = (255, 255, 0, 255)
+    GREEN  = (0, 255, 0, 255)
+    BLUE   = (0, 0, 255, 255)
+    PURPLE = (128, 0, 255, 255)
+    PINK   = (255, 0, 255, 255)
+    WHITE  = (255, 255, 255, 255)
+    GRAY   = (128, 128, 128, 255)
+    BLACK  = (0, 0, 0, 255)
     TRANSPARENT = (0, 0, 0, 0)
 
-    PRETTY_BLACK = (26, 26, 26)
-    # fmt: on
+    PRETTY_BLACK = (26, 26, 26, 255)
 
 
 class MakeImage:
@@ -41,7 +39,7 @@ class MakeImage:
 
     @staticmethod
     def type(b):
-        return what('', b)
+        return from_buffer(b[:2048]).split('/')[1]
 
     @classmethod
     def new(cls, size, color=Color.WHITE):
@@ -62,12 +60,12 @@ class MakeImage:
     def get_text_pos(self, draw, text, font):
         w, h = draw.textsize(text, font=font)
         W, H = self.size
-        return W - w, H - h
+        return W-w, H-h
 
     def get_image_pos(self, im):
         W, H = self.size
         w, h = im.size
-        return W - w, H - h
+        return W-w, H-h
 
     def resize(self, size, preserve_aspect=False):
         if preserve_aspect:
@@ -77,13 +75,13 @@ class MakeImage:
 
     def crop(self, size):
         W, H = self.size
-        cw, ch = W // 2, H // 2
+        cw, ch = W//2, H//2
         w, h = size
 
-        left = cw - w // 2
-        top = ch - h // 2
-        right = cw + w // 2
-        bottom = ch + h // 2
+        left = cw-w//2
+        top = ch-h//2
+        right = cw + w//2
+        bottom = ch + h//2
 
         self.img = self.img.crop((left, top, right, bottom))
 
@@ -100,15 +98,15 @@ class MakeImage:
     def calc(size, position=None, move=(0, 0)):
         w, h = size
         if position == 'center':
-            return tuple(map(sum, zip((w // 2, h // 2), move)))
+            return tuple(map(sum, zip((w//2, h//2), move)))
         if position == 'top':
-            return tuple(map(sum, zip((w // 2, 0), move)))
+            return tuple(map(sum, zip((w//2, 0), move)))
         if position == 'right':
-            return tuple(map(sum, zip((w, h // 2), move)))
+            return tuple(map(sum, zip((w, h//2), move)))
         if position == 'bottom':
-            return tuple(map(sum, zip((w // 2, h), move)))
+            return tuple(map(sum, zip((w//2, h), move)))
         if position == 'left':
-            return tuple(map(sum, zip((0, h // 2), move)))
+            return tuple(map(sum, zip((0, h//2), move)))
         return move
 
     def text(
@@ -146,11 +144,12 @@ class MakeImage:
 
     def circular_thumbnail(self):
         w, h = self.size
-        w, h = w * 3, h * 3
+        w, h = w*3, h*3
         mask = Image.new('L', (w, h), 0)
 
-        # Place the entire mask in the center of the image, without the 5, part of the mask's edges is slightly cut
-        ImageDraw.Draw(mask).ellipse((5, 5, w - 5, h - 5), fill=255)
+        # Place the entire mask in the center of the image,
+        # without the 5, part of the mask's edges is slightly cut
+        ImageDraw.Draw(mask).ellipse((5, 5, w-5, h-5), fill=255)
         mask = mask.resize(self.size, Image.BICUBIC)
         self.img = ImageOps.fit(self.img, mask.size, Image.BICUBIC)
         self.img.putalpha(mask)
@@ -159,7 +158,7 @@ class MakeImage:
         self.img.seek(n_frame)
         self.save('tmp.webp')
         with open('tmp.webp', 'rb') as tmp:
-            tmp = self.__class__.from_bytes(tmp.read())
+            tmp = MakeImage.from_bytes(tmp.read())
         Path('tmp.webp').unlink(missing_ok=True)
         return tmp
 
@@ -167,14 +166,14 @@ class MakeImage:
         # The border size must be an even number
         W, H = self.size
 
-        mask = self.img.copy().resize((W + size * 2, H + size * 2))
-        fill = Image.new('RGBA', (W + size * 2, H + size * 2), color)
-        bg = Image.new('RGBA', (W + size * 2, H + size * 2), Color.TRANSPARENT)
+        mask = self.img.copy().resize((W + size*2, H + size*2))
+        fill = Image.new('RGBA', (W + size*2, H + size*2), color)
+        bg = Image.new('RGBA', (W + size*2, H + size*2), Color.TRANSPARENT)
 
         w, h = bg.size
 
         bg.paste(fill, mask=mask)
-        bg.paste(self.img, ((w - W) // 2, (h - H) // 2), self.img)
+        bg.paste(self.img, ((w-W)//2, (h-H)//2), self.img)
 
         self.img = bg
 
@@ -206,9 +205,9 @@ class ProgressBar(MakeImage):
 
         for y in range(bg_fill.size[1]):
             for x in range(bg_fill.size[0]):
-                if pixdata[x, y] == (*self.bg, 255):
-                    pixdata[x, y] = (*self.color, 255)
+                if pixdata[x, y] == self.bg:
+                    pixdata[x, y] = self.color
 
-        bg_fill = bg_fill.crop((0, 0, px * 2, h))
+        bg_fill = bg_fill.crop((0, 0, px*2, h))
         bg.paste(bg_fill, mask=bg_fill)
         self.img = bg.resize((w, h), Image.BICUBIC)
