@@ -8,7 +8,7 @@ from subprocess import run
 from contextlib import suppress
 from unicodedata import normalize
 
-from magic import from_buffer
+from filetype import guess_mime
 from ujson import dumps, loads, dump
 from aiohttp import request
 from pybase64 import b64encode
@@ -344,11 +344,10 @@ class File:
 
         b = await self.get(file)
 
-        # python-magic using at least the first 2048 bytes,
-        # as less can produce incorrect identification
+        # Only first 261 bytes representing the max file header is required
         #
-        # https://github.com/ahupp/python-magic#usage
-        type_ = from_buffer(b[:2048], mime=True).split('/')
+        # https://github.com/h2non/filetype.py#features
+        type_ = guess_mime(b[:261]).split('/')
 
         if type_[1] == 'gif':
                 return {
